==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapResourceEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapResourceEntity.AbstractMapResourceEntity implements org.keycloak.models.map.authorization.entity.MapResourceEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> entityFieldDelegate;
    public MapResourceEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDisplayName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setDisplayName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getUris() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS);
    }
    @SuppressWarnings("unchecked") @Override public void setUris(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIconUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setIconUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOwner() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER);
    }
    @SuppressWarnings("unchecked") @Override public void setOwner(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOwnerManagedAccess() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS);
    }
    @SuppressWarnings("unchecked") @Override public void setOwnerManagedAccess(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getScopeIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void setScopeIds(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceEntityFieldDelegate.java <==
package org.keycloak.models.map.authorization.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapResourceEntityFieldDelegate extends org.keycloak.models.map.authorization.entity.MapResourceEntity.AbstractMapResourceEntity implements org.keycloak.models.map.authorization.entity.MapResourceEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> entityFieldDelegate;
    public MapResourceEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authorization.entity.MapResourceEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDisplayName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setDisplayName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getUris() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS);
    }
    @SuppressWarnings("unchecked") @Override public void setUris(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIconUri() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI);
    }
    @SuppressWarnings("unchecked") @Override public void setIconUri(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getOwner() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER);
    }
    @SuppressWarnings("unchecked") @Override public void setOwner(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOwnerManagedAccess() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS);
    }
    @SuppressWarnings("unchecked") @Override public void setOwnerManagedAccess(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceServerId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceServerId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getScopeIds() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS);
    }
    @SuppressWarnings("unchecked") @Override public void setScopeIds(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS, p0);
    }
}
